@@ -33,4 +33,8 @@ void chum_set_easy_game(gboolean b);
 
 gboolean start_3_6_game(gpointer data);
 
+
+//Start game over the network (by teacher)
+void chum_remote_game_starter(gpointer data, gint16 track_id);
+
 #endif  /*  _CHUM_H_  */
