@@ -419,7 +419,7 @@ void singinggame_start_songselection(){
 		column_counter++;
 		}
 
-	gchar* mentor_speech;
+	const gchar* mentor_speech;
 
 	TangleLayout* layout = tangle_widget_get_layout(TANGLE_WIDGET(container));
 	GList* trick_list = tangle_layout_get_tricks(layout);
