@@ -111,7 +111,7 @@ return sin (phasing(clutter_timeline_get_progress (clutter_alpha_get_timeline (a
 static int tempo_table[] = {0,140,110,90}; //variation1 is 140bpm, variation2 is 110bpm, variation3 is 90pbm
 
 //On advanced game, variation is not used, they are all using same set of sample_buttons
-ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(jammo_theme* theme, gchar* themename, guint variation, guint id){
+ClutterActor* theme_give_sample_button_for_this_theme_and_variation_for_this_id(jammo_theme* theme, const gchar* themename, guint variation, guint id){
 	if (theme->sample_button_array == NULL)
 		return NULL;
 	JammoSampleButton* sb = JAMMO_SAMPLE_BUTTON(g_ptr_array_index(theme->sample_button_array, id)); //clone this!
@@ -171,7 +171,7 @@ static int static_counter_for_id = 0;
 /*
 This function creates new jammo_sample_button from given parameters and put it to given parent ClutterActor.
 */
-static void create_samplebutton(gchar* themename, gchar* variation, gchar* imagefile, gchar* soundfile, gfloat x, gfloat y,jammo_theme* theme,TangleWidget* container_for_buttons,TangleWidget* parent){
+static void create_samplebutton(const gchar* themename, const gchar* variation, const gchar* imagefile, const gchar* soundfile, gfloat x, gfloat y,jammo_theme* theme,TangleWidget* container_for_buttons,TangleWidget* parent){
 	gchar *full_image = g_strdup_printf("themes/%s/%s/%s",themename,variation,imagefile);
 	//printf("image file: '%s'\n",full_image);
 
@@ -501,8 +501,8 @@ jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listeni
 	gboolean use_two_tracks=FALSE;
 
 
-	gchar* background_color_code = "some_default";
-	gchar* backing_track_filepath = "no_any_backing_track";
+	const gchar* background_color_code = "some_default";
+	const gchar* backing_track_filepath = "no_any_backing_track";
 
 	int disabled_slots_for_begin = 0;
 	int disabled_slots_for_end = 0;
