@@ -18,7 +18,7 @@
 #include "../pen_gesture/login_screen.h"
 
 
-
+//#define SKIP_LOGIN 1
 static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 	ClutterActor* actor;
 
@@ -49,12 +49,12 @@ static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 
 
 /*
-If user doesn't click door, there are timeout. Timeout calls welcome_door_clicked, but action==NULL.
+If user doesn't click door, there are timeout. Timeout calls welcome_door_clicked, but tangle_actor==NULL.
 All this hazzling is needed because user can click (or double click) very same time than timeout triggers.
 */
 static gboolean door_is_opening = FALSE; //Or opened already.
-void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	if (door_is_opening && action == NULL)
+void welcome_door_clicked(TangleActor* tangle_actor, gpointer data){
+	if (door_is_opening && tangle_actor == NULL)
 		return;
 
 	door_is_opening = TRUE;
