@@ -8,21 +8,22 @@
 
 static void end_avatar_view();
 
-ClutterContainer *partsList;
-ClutterContainer *avatarImage = 0;
 typedef enum{BLACK, BLOND, BLUE, BROWN, DARKBROWN, GRAY, ORANGE, VIOLET, WHITE}HAIR_COLOR;
 typedef enum{BROWN_HEAD, DARK_HEAD, PINK_HEAD, YELLOW_HEAD}HEADS;
-const int NUMBEROFCOLORS = 9;
-const int NUMBEROFHEADS = 4;
-HAIR_COLOR hairColor;
-HEADS heads = YELLOW_HEAD;
-char currentHairType[50];
-gboolean hairsInList = FALSE;
-ClutterActor *instrumentBackground = 0;
-Avatar avatar = {0,0,0,0};
-TextField hobbiesTextField;
-TextField nameTextField;
-TextField genderTextField;
+
+static ClutterContainer *partsList;
+static ClutterContainer *avatarImage = 0;
+static const int NUMBEROFCOLORS = 9;
+static const int NUMBEROFHEADS = 4;
+static HAIR_COLOR hairColor;
+static HEADS heads = YELLOW_HEAD;
+static char currentHairType[50];
+static gboolean hairsInList = FALSE;
+static ClutterActor *instrumentBackground = 0;
+static Avatar avatar = {0,0,0,0};
+static TextField hobbiesTextField;
+static TextField nameTextField;
+static TextField genderTextField;
 
 static void change_hair_type() ;
 void start_avatar_editor(){
