@@ -64,7 +64,7 @@ void backingtrack_selection_set_track_view(ClutterActor* actor){
 	static_backingtrack = actor;
 }
 
-void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
+gboolean backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
 	gchar* message = g_strdup_printf("Backintrack-selection: Song '%s' clicked",name);
 	cem_add_to_log(message,J_LOG_USER_ACTION);
@@ -135,10 +135,12 @@ void backingtrack_song_clicked (TangleButton* tanglebutton, gpointer none){
 
 	g_signal_connect(adhoc_sequencer, "stopped", G_CALLBACK(on_sequencer_stopped), NULL);
 	jammo_sequencer_play(adhoc_sequencer);
+
+	return TRUE;
 }
 
 
-void backingtrack_selection_vocal_clicked(TangleButton* tanglebutton, gpointer none){
+gboolean backingtrack_selection_vocal_clicked(TangleButton* tanglebutton, gpointer none){
 	vocal_selected = tangle_button_get_selected(tanglebutton);
 
 	if (vocal_selected) {
@@ -149,9 +151,11 @@ void backingtrack_selection_vocal_clicked(TangleButton* tanglebutton, gpointer n
 	else {
 		 cem_add_to_log("Backintrack-selection: vocal deselected",J_LOG_USER_ACTION);
 	}
+
+	return TRUE;
 }
 
-void backingtrack_selection_melodical_clicked(TangleButton* tanglebutton, gpointer none){
+gboolean backingtrack_selection_melodical_clicked(TangleButton* tanglebutton, gpointer none){
 	melodic_selected = tangle_button_get_selected(tanglebutton);
 
 	if (melodic_selected) {
@@ -162,6 +166,8 @@ void backingtrack_selection_melodical_clicked(TangleButton* tanglebutton, gpoint
 	else {
 		 cem_add_to_log("Backintrack-selection: melodic deselected",J_LOG_USER_ACTION);
 	}
+
+	return TRUE;
 }
 
 static void end_backingtrack_selection() {
@@ -186,7 +192,7 @@ static void end_backingtrack_selection() {
 }
 
 
-void backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer none){
+gboolean backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Backintrack-selection: OK clicked",J_LOG_USER_ACTION);
 
 	if (last_played_filename) {
@@ -199,13 +205,13 @@ void backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer none
 				g_object_set(track,"filename",last_played_filename,NULL);
 			} else {
 					cem_add_to_log("Backintrack-selection: No track found.",J_LOG_FATAL);
-				return;
+				return TRUE;
 			}
 
 			//image
 			gchar* image_file = g_build_filename(DATA_DIR, "backingtracks",image_name_for_last_played,NULL);
 			//printf ("image_file '%s'\n",image_file);
-			ClutterActor* new_back = clutter_texture_new_from_file(image_file, NULL);
+			ClutterActor* new_back = tangle_texture_new(image_file);
 			if (new_back==NULL) {
 				cem_add_to_log("Backintrack-selection: No image found, using gray texture",J_LOG_FATAL);
 				new_back = clutter_rectangle_new_with_color (clutter_color_new(100,100,100,100));
@@ -219,13 +225,16 @@ void backingtrack_selection_ok_clicked(TangleButton* tanglebutton, gpointer none
 		}
 	}
 
-end_backingtrack_selection();
+	end_backingtrack_selection();
+	return TRUE;
 }
 
 
-void backingtrack_selection_cancel_clicked(TangleButton* tanglebutton, gpointer none){
+gboolean backingtrack_selection_cancel_clicked(TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Backintrack-selection: cancel clicked",J_LOG_USER_ACTION);
 	end_backingtrack_selection();
+
+	return TRUE;
 }
 
 #define step_height 130
@@ -240,19 +249,23 @@ static void roll_song_list(int direction) {
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 250, "offset-y", old_value + (direction*step_height), NULL);
 }
 
-void backingtrack_up_arrow_clicked(TangleButton* tanglebutton, gpointer none){
+gboolean backingtrack_up_arrow_clicked(TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Backintrack-selection: up arrow clicked",J_LOG_USER_ACTION);
 	roll_song_list(-1); //up
+
+	return TRUE;
 }
 
 
-void backingtrack_down_arrow_clicked(TangleButton* tanglebutton, gpointer none){
+gboolean backingtrack_down_arrow_clicked(TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Backintrack-selection: down arrow clicked",J_LOG_USER_ACTION);
 	roll_song_list(1); //down
+
+	return TRUE;
 }
 
 //Set clamping after view is visible. It does not harm when called second time.
-void backingtrack_selection_show_completed(TangleAction *tangleaction, GObject *source, const gchar *trigger, TangleProperties *properties){
+void backingtrack_selection_show_completed(TangleActor* tangle_actor, gpointer data){
 	clear_list_and_make_new(); //for visible_borders
 	ClutterActor* actor = jammo_get_actor_by_id("backingtrack-selection-container");
 	if (actor) {
