@@ -29,7 +29,7 @@ void getDiscussion(ClutterActor *element);
 void getThread(ClutterActor *element);
 void start_discussionthreads();
 void start_addthread_view();
-void discuss_change_to_add_thread_view();
+gboolean discuss_change_to_add_thread_view(TangleActor *actor, gpointer data);
 void add_new_thread();
 void end_discuss();
 
