@@ -507,7 +507,8 @@ b) instrument_gui_start(NULL,sequencer, TANGLE_WIDGET(track->track_view));
 */
 void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* slider_container)
 {
-	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	static_sequencer = jammo_sequencer_new();
+	//JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	handler_for_sequencer_stop = g_signal_connect(static_sequencer, "stopped", G_CALLBACK(instrument_gui_on_sequencer_stopped), NULL);
 
 	ClutterActor* mainview;
@@ -533,6 +534,7 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* sli
 		clutter_actor_show(jammo_get_actor_by_id("instrument-slider"));
 
 		g_object_get(slider_container,"track",&static_slider_track,NULL);
+		jammo_sequencer_add_track(static_sequencer,JAMMO_TRACK(static_slider_track));
 
 		//Make ad-hoc-track using same type
 		int type;
@@ -564,6 +566,7 @@ void instrument_gui_start (JammoMiditrackView* miditrack_view, TangleWidget* sli
 		g_object_get(miditrack_view,"track",&track,NULL);
 		g_signal_connect (track, "report-note", G_CALLBACK (visualize_playback),NULL);
 
+		jammo_sequencer_add_track(static_sequencer,track);
 		int type;
 		g_object_get(track,"instrument-type",&type,NULL);
 		gchar* message = g_strdup_printf("Starting instrument-gui with instrument-type: %d",type);
