@@ -11,7 +11,7 @@ This file contains the functionality of JamMo Songs menu.
 #include <meam/jammo-sample.h>
 
 void start_jammosongs();
-void end_jammosongs(TangleButton *tanglebutton, gpointer none);
+gboolean end_jammosongs(TangleButton *tanglebutton, gpointer none);
 gboolean add_song_to_list(char* loop_name, int number, guint32 user_id);
 void record_voice_comment();
 void stop_recording();
