@@ -606,20 +606,22 @@ void level1_task7_started(JammoGameTask* task) {
 	//printf("n_slots: %d \n",n_slots);
 
 	gboolean free_slot[8]={TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE}; //FIXME: use n_slots
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(track_view)); children; children = children->next) {
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
+	
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(track_view), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 
-	guint slot = jammo_editing_track_view_get_sample_button_slot(JAMMO_EDITING_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(children->data));
+		guint slot = jammo_editing_track_view_get_sample_button_slot(JAMMO_EDITING_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(child));
 
-	float width = clutter_actor_get_width(CLUTTER_ACTOR(children->data));
-	//printf("reserved slots %d, %f\n",slot, width); //width is 75=slot
-	free_slot[slot]=FALSE;
-	if (width>80) //FIXME: check width of slots
-		free_slot[slot+1]=FALSE;
-	if (width>160)
-		free_slot[slot+2]=FALSE;
-	if (width>310)
-		free_slot[slot+3]=FALSE;
+		float width = clutter_actor_get_width(child);
+		//printf("reserved slots %d, %f\n",slot, width); //width is 75=slot
+		free_slot[slot]=FALSE;
+		if (width>80) //FIXME: check width of slots
+			free_slot[slot+1]=FALSE;
+		if (width>160)
+			free_slot[slot+2]=FALSE;
+		if (width>310)
+			free_slot[slot+3]=FALSE;
 	}
 
 	int index=-1;
