@@ -223,6 +223,7 @@ if (load_only_backingtrack){
 			if(strncmp(track_type, "EditingTrack", 12) == 0) {
 				gint e_track_type=JAMMO_SAMPLE_UNTYPED;
 				const gchar* editing_track_type;
+				gint slot_width=-1; //-1 means use default value.
 
 				//string
 				sub_node = json_object_get_member (sub_object, "editing-track-type");
@@ -238,11 +239,21 @@ if (load_only_backingtrack){
 				if (enum_value)
 					e_track_type = enum_value->value;
 
-				track_view = sequencer_track_view_create_editing_track(muted,volume,e_track_type,name_of_track);
+				//int
+				sub_node = json_object_get_member (sub_object, "slot-width");
+				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
+					slot_width = json_node_get_int (sub_node);
+				}
+
+				track_view = sequencer_track_view_create_editing_track(muted,volume,e_track_type,slot_width,name_of_track);
 
 				//Array
 				sub_node = json_object_get_member (sub_object, "samples");
 				load_this_sample_array_to_this_track_view(sub_node,JAMMO_EDITING_TRACK_VIEW(track_view),TRUE); //TRUE=reactive
+				//Group game
+				if (sequencer_get_group_composition()) {
+					jammo_collaboration_group_composition_new_view(G_OBJECT(sequencer_get_group_composition()), CLUTTER_ACTOR(track_view));
+				}
 			} //Editing-track over
 
 			//VirtualInstrumentTrack
@@ -497,6 +508,10 @@ static void leave_fullsequencer() {
 	jammo_sequencer_stop(sequencer);
 	//Autosaving?
 	//Confirmation?
+	if (sequencer_get_group_composition()) {
+		g_object_unref(sequencer_get_group_composition());
+		sequencer_set_group_composition(NULL);
+	}
 
 	tangle_view_unload(TANGLE_VIEW(current_levelview));
 	current_levelview=NULL;
