@@ -124,6 +124,8 @@ Will return NULL in error cases.
 Returns new just created sample, not actual sample from wheel.
 */
 static JammoSample* get_centermost_sample_from_loop_roll(ClutterActor* wheel) {
+	TangleActorIterator actor_iterator;
+	ClutterActor* child;
 	JammoSample* sample = NULL;
 	gfloat offset;
 	ClutterActorBox box;
@@ -131,12 +133,11 @@ static JammoSample* get_centermost_sample_from_loop_roll(ClutterActor* wheel) {
 	offset = clutter_actor_get_height(wheel) / 2.0;
 	//printf("offset = %f\n",offset);
 
-	GList* children;
-	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(wheel)); children; children = children->next) {
-		if (JAMMO_IS_SAMPLE_BUTTON(children->data)){
-			clutter_actor_get_allocation_box(CLUTTER_ACTOR(children->data), &box);
+	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(wheel), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
+		if (JAMMO_IS_SAMPLE_BUTTON(child)){
+			clutter_actor_get_allocation_box(child, &box);
 			if (box.y1 < offset && box.y2 > offset) {
-				sample = jammo_sample_new_from_existing(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(children->data)));
+				sample = jammo_sample_new_from_existing(jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(child)));
 				break;
 			}
 		}
@@ -818,7 +819,8 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 
 		//sound==NULL -> this is not really samplebutton: it can't be dragged at all.
 		if (new_button.sound==NULL)
-			g_object_set(sample_button,"drag-threshold-x",10000,NULL); //No dragging
+			//No dragging nor high-lighting
+			clutter_actor_set_reactive(sample_button,FALSE);
 		else
 			jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), loop_id);
 
