@@ -42,6 +42,7 @@ static int width_of_slot = 40;
 
 //We get these as parameters
 static int number_of_slots = -1;
+static guint64 duration_of_the_track = 0; //This is saved on files.
 
 gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpointer user_data);
 gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer user_data);
@@ -258,6 +259,27 @@ gboolean sequencer_volumebar_used (ClutterAction* scroll_action, gpointer none){
 }
 
 
+/*
+ When volume-slider is visible stage is capturing all events.
+ Next release-event will end capturing.
+ */
+static gboolean stage_capture_events (ClutterActor* actor, ClutterEvent* event, gpointer user_data)  {
+	if (event->type == CLUTTER_BUTTON_RELEASE){
+		g_signal_handlers_disconnect_by_func(actor, stage_capture_events,NULL);
+
+		//Hide volume-slider
+		ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
+		clutter_actor_hide(volume_container);
+
+		//De-select pressed volume-button.
+		tangle_button_set_selected(last_pressed_volume_button,FALSE);
+		last_pressed_volume_button=NULL;
+	}
+
+	return FALSE;
+}
+
+
 
 /**
 Each tracks share one volumebar.
@@ -265,6 +287,8 @@ Each tracks share one volumebar.
   else name of buttons parent (=control-panel-widget) is used for jammo_get_actor_by_id (actors created from json)
 */
 gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer data) {
+	ClutterActor* stage = clutter_stage_get_default();
+	g_signal_connect(stage, "captured-event", G_CALLBACK(stage_capture_events), NULL);
 
 	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(tanglebutton));
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
@@ -307,28 +331,20 @@ gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpointer d
 	gfloat current_volume = jammo_playing_track_get_volume(jammotrack);
 	//printf("volume of this track is :%f\n",current_volume);
 
-	//When pressing already selected track, hide volume bar
-	if (last_pressed_volume_button==tanglebutton) {
-		clutter_actor_hide(volume_container);
-		g_object_set_data(G_OBJECT(volume_scroller),"track",NULL);
-		last_pressed_volume_button=NULL;
-	}
 
 	//Hide last pressed and put new value to volumebar from track
-	else {
-		clutter_actor_show(volume_container);
-		//-50 is height of the visible marker.
-		gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50)*current_volume;
-		//printf("new place: %f\n",new_place);
-		//Disconnect notify::offset-y for a while: we are making to change offset-y
-		g_signal_handlers_disconnect_by_func(scroll_action, sequencer_volumebar_used,NULL);
-		g_object_set(scroll_action, "offset-y", new_place, NULL);
-		g_signal_connect(scroll_action, "notify::offset-y", G_CALLBACK(sequencer_volumebar_used), NULL);
-		g_object_set_data(G_OBJECT(volume_scroller),"track",jammotrack);
-		if (last_pressed_volume_button)
-			tangle_button_set_selected(last_pressed_volume_button,FALSE);
-		last_pressed_volume_button=tanglebutton;
-		}
+	clutter_actor_show(volume_container);
+	//-50 is height of the visible marker.
+	gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-50)*current_volume;
+	//printf("new place: %f\n",new_place);
+	//Disconnect notify::offset-y for a while: we are making to change offset-y
+	g_signal_handlers_disconnect_by_func(scroll_action, sequencer_volumebar_used,NULL);
+	g_object_set(scroll_action, "offset-y", new_place, NULL);
+	g_signal_connect(scroll_action, "notify::offset-y", G_CALLBACK(sequencer_volumebar_used), NULL);
+	g_object_set_data(G_OBJECT(volume_scroller),"track",jammotrack);
+	if (last_pressed_volume_button)
+		tangle_button_set_selected(last_pressed_volume_button,FALSE);
+	last_pressed_volume_button=tanglebutton;
 
 	return FALSE;
 }
@@ -429,6 +445,7 @@ void sequencer_track_view_set_duration(guint64 duration) {
 
 	//Set static
 	number_of_slots = n_slots;
+	duration_of_the_track = duration;
 
 	//CURSOR IS NOT USED
 	//CURSOR
@@ -520,9 +537,9 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 
 
 
-ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, const gchar* name_of_track_view) {
+ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, gint slot_width, const gchar* name_of_track_view) {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
-	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
+	guint64 duration_of_tracks = duration_of_the_track; //this is static variable
 	//printf("Making editing track (duration: %" G_GUINT64_FORMAT ")\n", duration_of_tracks);
 
 	guint64 duration_of_one_slot;
@@ -540,9 +557,12 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 	track = JAMMO_TRACK(jammo_editing_track_new_fixed_duration(duration_of_tracks));
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(track));
 
+	if (slot_width==-1)
+		slot_width=width_of_slot; //static default value
+
 	//CHUM-track-view
 	ClutterActor* track_view_actor = jammo_editing_track_view_new(JAMMO_EDITING_TRACK(track),
-          number_of_slots, duration_of_one_slot, width_of_slot, track_height);
+          number_of_slots, duration_of_one_slot, slot_width, track_height);
 	clutter_actor_set_reactive(track_view_actor, TRUE);
 	g_object_set(track_view_actor, "line-every-nth-slot", 1, "sample-type", e_type,
         "name", name_of_track_view,
