@@ -37,7 +37,7 @@ enum {
 
 void sequencer_track_view_set_duration(guint64 duration);
 
-ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, const gchar* name_of_track_view);
+ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, gint slot_width, const gchar* name_of_track_view);
 ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, const gchar*
 name_of_track_view);
 ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, const gchar* audio, const gchar* image, const gchar* name_of_track_view);
