@@ -52,15 +52,14 @@ static void singing_gui_on_sequencer_stopped_played(JammoSequencer* sequencer, g
 	tangle_button_set_selected(TANGLE_BUTTON(jammo_get_actor_by_id("singing_play")),FALSE);
 }
 
-
-void singing_play_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean singing_play_clicked(TangleActor* actor, gpointer data){
 	cem_add_to_log("Play-button on singing-view pressed",J_LOG_USER_ACTION);
 	JammoSequencer* static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
 	if (playing) {
 		cem_add_to_log("Stop-button on singing-view pressed",J_LOG_USER_ACTION);
 		jammo_sequencer_stop (static_sequencer); //this will trigger singing_gui_on_sequencer_stopped_played
-		return;
+		return TRUE;
 	}
 
 	if (recording) {
@@ -74,18 +73,19 @@ void singing_play_clicked (TangleAction *action, GObject *source, const gchar *t
 	playing=TRUE;
 	g_signal_connect(static_sequencer, "stopped", G_CALLBACK(singing_gui_on_sequencer_stopped_played), NULL);
 	jammo_sequencer_play (static_sequencer);
+
+	return TRUE;
 }
 
 
-
-void singing_record_clicked  (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean singing_record_clicked (TangleActor* actor, gpointer data){
 	cem_add_to_log("Record-button on singing-view pressed",J_LOG_USER_ACTION);
 	JammoSequencer* static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 
 	if (recording) {
 		cem_add_to_log("(rec-)stop-button on singing-view pressed",J_LOG_USER_ACTION);
 		jammo_sequencer_stop (static_sequencer); //this will trigger singing_gui_on_sequencer_stopped_recorded
-		return;
+		return TRUE;
 	}
 
 	if (playing) {
@@ -112,11 +112,12 @@ void singing_record_clicked  (TangleAction *action, GObject *source, const gchar
 	recording=TRUE;
 	g_signal_connect(static_sequencer, "stopped", G_CALLBACK(singing_gui_on_sequencer_stopped_recorded), NULL);
 	jammo_sequencer_play (static_sequencer);
+
+	return TRUE;
 }
 
 
-
-void singing_gosequencer_clicked  (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+gboolean singing_gosequencer_clicked (TangleActor* actor, gpointer data) {
 	cem_add_to_log("Backtoseq-button on singing-view pressed",J_LOG_USER_ACTION);
 
 	//hide this
@@ -136,5 +137,7 @@ void singing_gosequencer_clicked  (TangleAction *action, GObject *source, const
 	jammo_recording_track_set_enabled(rec_track, FALSE); //disabling
 
 	return_to_fullsequencer_gui();
+
+	return TRUE;
 }
 
