@@ -7,6 +7,7 @@
 #include <meam/jammo-meam.h>
 #include <meam/jammo-sample.h>
 #include "../jammo.h"
+#include "../../cem/cem.h"
 #include "community_utilities.h"
 #include "jammosongs.h"
 #include "help.h"
@@ -31,7 +32,7 @@ void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int ind
 	messages 	= listOfMessages;
 	id 		= id_;
 
-	puts("starting thread...");
+	cem_add_to_log("starting thread...", J_LOG_DEBUG);
 
 	ClutterActor* thread_view = jammo_get_actor_by_id("single-thread-view");
 
@@ -69,7 +70,7 @@ void start_thread_view(GList* listOfMessages, gchar *id_, gchar *params, int ind
 		}
 	}
 	else
-	puts("can't find single-thread-view");
+	cem_add_to_log("can't find single-thread-view", J_LOG_ERROR);
 }
 
 gboolean text_comment_view(TangleActor* actor, gpointer data) {
@@ -118,9 +119,9 @@ void add_message_to_list(gpointer data, int i)
 		ClutterColor line_color = { 144, 148, 140, 255 };
 
 		ClutterActor* avatarBackground = clutter_group_new();
-		
-		clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), tangle_texture_new(
-						"/opt/jammo/communitymenu/community_avatarbackground_small.png"));
+		gchar* avatarbg_filename = g_strdup_printf("%s/communitymenu/community_avatarbackground_small.png", DATA_DIR);		
+
+		clutter_container_add_actor(CLUTTER_CONTAINER(avatarBackground), tangle_texture_new(avatarbg_filename));
 		ClutterActor* writer = tangle_button_new_with_background_actor(avatarBackground);
 		
 		ClutterActor* name = clutter_text_new_full(TEXT_NORMAL, msg->sender, &text_color);
@@ -140,6 +141,7 @@ void add_message_to_list(gpointer data, int i)
 		}else{
 			clutter_actor_set_position(name, 80, 20); 
 		}
+		g_free(avatarbg_filename);
 
 		clutter_actor_set_size(name,((35*10)+30), 41);
 		clutter_text_set_max_length(CLUTTER_TEXT(name), 20);
@@ -166,15 +168,15 @@ void add_message_to_list(gpointer data, int i)
 		if(msg->type == VOICE_COMMENT){
 			
 			strcpy(filepath, msg->filepath);
-
-			printf("Filepath on:%s\n", filepath);
-
+			
+			gchar* play_button_filename = g_strdup_printf("%s/buttons/play-button.png", DATA_DIR);
 			ClutterActor* play_button = 0;
-			play_button = tangle_button_new_with_background_actor(tangle_texture_new("/opt/jammo/buttons/play-button.png")); 
+			play_button = tangle_button_new_with_background_actor(tangle_texture_new(play_button_filename)); 
 			clutter_actor_set_position(play_button, 400, 1);
 			clutter_container_add_actor(listContainer, play_button);
 
 			g_signal_connect_swapped(CLUTTER_ACTOR(play_button), "clicked", G_CALLBACK(play_selected_loop), filepath);
+			g_free(play_button_filename);
 
 		}
 
@@ -198,8 +200,8 @@ gboolean add_comment(TangleActor* actor, gpointer data) {
 
 	if(clutter_text_get_text(CLUTTER_TEXT(text.text)) == NULL || (strcmp(clutter_text_get_text(CLUTTER_TEXT(text.text)), "") == FALSE))
 	{
-		printf("No text entered\n");
-		return TRUE;
+		cem_add_to_log("No text entered\n", J_LOG_DEBUG);
+		return FALSE;
 	}
 
 	clear_container(messageList);
