@@ -126,11 +126,13 @@ void save_composition(const gchar* folder, const gchar* to_filename, ClutterActo
 				fprintf(ofp,"\t\"editing-track-type\" : \"%s\",\n",nick);
 			}
 
-			fprintf(ofp,"\t\"samples\" : [");
-
 			gfloat slot_size;
 			g_object_get(track_view,"slot-width",&slot_size,NULL);
 			//printf("slot_size '%lf'\n",slot_size);
+			gint slot_width = slot_size;
+			fprintf(ofp,"\t\"slot-width\" : %d,\n",slot_width);
+
+			fprintf(ofp,"\t\"samples\" : [");
 
 			TangleActorIterator actor_iterator2;
 			ClutterActor* child;
