@@ -75,11 +75,14 @@ ClutterActor* jammo_mentor_new(ClutterActor* actor, gfloat standby_scale, gfloat
 }
 
 gfloat jammo_mentor_get_standby_scale(JammoMentor* mentor) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), 0.0);
 
 	return mentor->priv->standby_scale;
 }
 
 void jammo_mentor_set_standby_scale(JammoMentor* mentor, gfloat scale) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (mentor->priv->standby_scale != scale) {
 		mentor->priv->standby_scale = scale;
 		if (!mentor->priv->active_sample) {
@@ -90,11 +93,14 @@ void jammo_mentor_set_standby_scale(JammoMentor* mentor, gfloat scale) {
 }
 
 gfloat jammo_mentor_get_active_scale(JammoMentor* mentor) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), 0.0);
 
 	return mentor->priv->active_scale;
 }
 
 void jammo_mentor_set_active_scale(JammoMentor* mentor, gfloat scale) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (mentor->priv->active_scale != scale) {
 		mentor->priv->active_scale = scale;
 		if (mentor->priv->active_sample) {
@@ -105,22 +111,32 @@ void jammo_mentor_set_active_scale(JammoMentor* mentor, gfloat scale) {
 }
 
 void jammo_mentor_speak(JammoMentor* mentor, const gchar* speech) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	speak(mentor, speech, FALSE, 0.0, 0.0, NULL, NULL);
 }
 
 void jammo_mentor_speak_with_callback(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	speak(mentor, speech, FALSE, 0.0, 0.0, callback, user_data);
 }
 
 void jammo_mentor_speak_and_highlight(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	speak(mentor, speech, TRUE, offset_x, offset_y, NULL, NULL);
 }
 
 void jammo_mentor_speak_and_highlight_with_callback(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	speak(mentor, speech, TRUE, offset_x, offset_y, callback, user_data);
 }
 
 void jammo_mentor_speak_once(JammoMentor* mentor, const gchar* speech) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
 		speak(mentor, speech, FALSE, 0.0, 0.0, NULL, NULL);
@@ -128,6 +144,8 @@ void jammo_mentor_speak_once(JammoMentor* mentor, const gchar* speech) {
 }
 
 void jammo_mentor_speak_once_with_callback(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
 		speak(mentor, speech, FALSE, 0.0, 0.0, callback, user_data);
@@ -135,6 +153,8 @@ void jammo_mentor_speak_once_with_callback(JammoMentor* mentor, const gchar* spe
 }
 
 void jammo_mentor_speak_and_highlight_once(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
 		speak(mentor, speech, TRUE, offset_x, offset_y, NULL, NULL);
@@ -142,6 +162,8 @@ void jammo_mentor_speak_and_highlight_once(JammoMentor* mentor, const gchar* spe
 }
 
 void jammo_mentor_speak_and_highlight_once_with_callback(JammoMentor* mentor, const gchar* speech, gfloat offset_x, gfloat offset_y, JammoMentorSpokenCallback callback, gpointer user_data) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (!g_list_find_custom(mentor->priv->spoken_speeches, speech, (GCompareFunc)g_strcmp0)) {
 		mentor->priv->spoken_speeches = g_list_prepend(mentor->priv->spoken_speeches, g_strdup(speech));
 		speak(mentor, speech, TRUE, offset_x, offset_y, callback, user_data);
@@ -149,6 +171,8 @@ void jammo_mentor_speak_and_highlight_once_with_callback(JammoMentor* mentor, co
 }
 
 void jammo_mentor_shut_up(JammoMentor* mentor) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (mentor->priv->active_sample) {
 		mentor->priv->interrupted = TRUE;
 		jammo_sample_stop(mentor->priv->active_sample);
@@ -156,15 +180,20 @@ void jammo_mentor_shut_up(JammoMentor* mentor) {
 }
 
 const gchar* jammo_mentor_get_idle_speech(JammoMentor* mentor) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), NULL);
 
 	return mentor->priv->idle_speech;
 }
 
 void jammo_mentor_set_idle_speech(JammoMentor* mentor, const gchar* speech) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	jammo_mentor_set_idle_speech_with_callback(mentor, speech, NULL, NULL);
 }
 
 void jammo_mentor_set_idle_speech_with_callback(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (g_strcmp0(mentor->priv->idle_speech, speech)) {
 		g_free(mentor->priv->idle_speech);
 		mentor->priv->idle_speech = g_strdup(speech);
@@ -177,11 +206,14 @@ void jammo_mentor_set_idle_speech_with_callback(JammoMentor* mentor, const gchar
 }
 
 gulong jammo_mentor_get_idle_timeout(JammoMentor* mentor) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), 0);
 
 	return mentor->priv->idle_timeout;
 }
 
 void jammo_mentor_set_idle_timeout(JammoMentor* mentor, gulong milliseconds) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (mentor->priv->idle_timeout != milliseconds) {
 		mentor->priv->idle_timeout = milliseconds;
 		set_idle_timeout(mentor, TRUE);
@@ -190,17 +222,22 @@ void jammo_mentor_set_idle_timeout(JammoMentor* mentor, gulong milliseconds) {
 }
 
 const gchar* jammo_mentor_get_language(JammoMentor* mentor) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), NULL);
 
 	return mentor->priv->language;
 }
 
 void jammo_mentor_set_language(JammoMentor* mentor, const gchar* language) {
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	if (mentor->priv->language)
 		g_free(mentor->priv->language);
 	mentor->priv->language = g_strdup(language);
 }
 
 void jammo_mentor_set_passive(JammoMentor* mentor, gboolean passive){
+	g_return_if_fail(JAMMO_IS_MENTOR(mentor));
+
 	mentor->priv->passive_mode=passive;
 	if (passive) {
 		cem_add_to_log("Mentor goes to passive mode",J_LOG_DEBUG);
@@ -221,6 +258,7 @@ void jammo_mentor_set_passive(JammoMentor* mentor, gboolean passive){
 
 
 gboolean jammo_mentor_get_device_locked(JammoMentor* mentor) {
+	g_return_val_if_fail(JAMMO_IS_MENTOR(mentor), FALSE);
 
 	return mentor->priv->device_locked;
 }
