@@ -108,25 +108,25 @@ void configure_release_directories(){
 
 
 
-gchar* configure_get_jammo_directory(){
+const gchar* configure_get_jammo_directory(){
 	return JAMMO_DIRECTORY;
 }
 
-gchar* configure_get_compositions_directory(){
+const gchar* configure_get_compositions_directory(){
 	return COMPOSITIONS_DIRECTORY;
 }
 
-gchar* configure_get_singings_directory(){
+const gchar* configure_get_singings_directory(){
 	return SINGINGS_DIRECTORY;
 }
 
-gchar* configure_get_projects_directory(){
+const gchar* configure_get_projects_directory(){
 	return PROJECTS_DIRECTORY;
 }
 
-gchar* configure_get_finalized_directory(){
+const gchar* configure_get_finalized_directory(){
 	return FINALIZED_DIRECTORY;
 }
-gchar* configure_get_log_directory(){
+const gchar* configure_get_log_directory(){
 	return LOG_DIRECTORY;
 }
