@@ -45,10 +45,11 @@ public:
 	// Get id
 	guint32 GetId();
 	
-	guint loadEncryptedProfile(gchar* _username);
+	guint loadEncryptedProfile(const gchar* _username);
 	guint reloadEncryptedProfile();
 	gboolean saveEncryptedProfile();
-	gboolean changeLoadedUser(gchar* _username);
+	gboolean changeLoadedUser(const gchar* _username);
+	void clearLoadedUser();
 	gboolean deserializeProfile(gchar* _profile);
 	gchar* serializeProfile();
 	
@@ -108,7 +109,7 @@ void log_wrap(char* msg, int info);
  *
  * Use the struct only through functions described here!
  */
-ProfileManager* profilemanager_new_manager();
+ProfileManager* profilemanager_get_manager();
 
 
 /* Delete profile manager
@@ -226,10 +227,11 @@ void profilemanager_reset_points(ProfileManager* _aManager);
 
 /* For encrypted profile data */
 
-guint profilemanager_storage_load_profile(ProfileManager* _aManager, gchar* _username);
+guint profilemanager_storage_load_profile(ProfileManager* _aManager, const gchar* _username);
 guint profilemanager_storage_reload_profile(ProfileManager* _aManager);
 gboolean profilemanager_storage_save_profile(ProfileManager* _aManager);
 gboolean profilemanager_storage_change_profile(ProfileManager* _aManager, gchar* _username);
+void profilemanager_storage_clear_profile(ProfileManager* _aManager);
 guchar* profilemanager_storage_get_password_salt(ProfileManager* _aManager);
 guchar* profilemanager_storage_get_password_hash(ProfileManager* _aManager);
 guchar* profilemanager_storage_get_profile_hash(ProfileManager* _aManager);
