@@ -422,8 +422,8 @@ gboolean StorageAgent::setSalt(guchar* _salt)
 	// Clear old salt
 	if(salt != NULL) g_free(salt);
 
-	salt = (guchar*)g_malloc(sizeof(guchar*)*AES_SALT_LENGTH);
-	memset(salt,0,AES_SALT_LENGTH);
+	salt = g_new0(guchar,sizeof(guchar)*AES_SALT_LENGTH);
+
 	g_memmove(&salt[0],_salt,AES_SALT_LENGTH);
 	
 	return TRUE;
@@ -437,8 +437,8 @@ gboolean StorageAgent::setPasswordHash(guchar* _password_hash)
 	// Clear old hash
 	if(password_hash != NULL) g_free(password_hash);
 	
-	password_hash = (guchar*)g_malloc(sizeof(guchar*)*SHA_HASH_LENGTH);
-	memset(password_hash,0,SHA_HASH_LENGTH);
+	password_hash = g_new0(guchar,sizeof(guchar)*SHA_HASH_LENGTH);
+
 	g_memmove(&password_hash[0],_password_hash,SHA_HASH_LENGTH);
 	
 	return TRUE;
@@ -450,13 +450,13 @@ gboolean StorageAgent::setEncryptedProfile(guchar* _profile_hash, guchar* _encry
 	if(_profile_hash == NULL || _encrypted_profile == NULL || _e_profile_size == 0) return FALSE;
 	
 	if(profile_hash != NULL) g_free(profile_hash);
-	profile_hash = (guchar*)g_malloc(sizeof(guchar*)*SHA_HASH_LENGTH);
-	memset(profile_hash,0,SHA_HASH_LENGTH);
+	profile_hash = g_new0(guchar,sizeof(guchar)*SHA_HASH_LENGTH);
+
 	g_memmove(&profile_hash[0],_profile_hash,SHA_HASH_LENGTH);
 	
 	if(encrypted_profile != NULL) g_free(encrypted_profile);
-	encrypted_profile = (guchar*)g_malloc(sizeof(guchar*)*_e_profile_size);
-	memset(encrypted_profile,0,_e_profile_size);
+	encrypted_profile = g_new0(guchar,sizeof(guchar)*_e_profile_size);
+
 	g_memmove(&encrypted_profile[0],_encrypted_profile,_e_profile_size);
 	
 	encrypted_profile_size = _e_profile_size;
@@ -503,7 +503,7 @@ void StorageAgent::clearEncryptedData()
 /* Read encrypted profile - raw
 *  parameters: username, password hash, salt, profile data hash, encrypted profile data, profile length
 */
-gint StorageAgent::readProfile(gchar* username)
+gint StorageAgent::readProfile(const gchar* username)
 {
 	gchar* profilefile = g_strjoin(NULL,username,PROFILE_FILE_EXT,NULL);
 	gchar* filename = g_build_filename(configure_get_jammo_directory(),JAMMOPROFILE,profilefile,NULL);
@@ -515,10 +515,6 @@ gint StorageAgent::readProfile(gchar* username)
 	// Test if profile file exists;
 	if(g_file_test(filename,G_FILE_TEST_IS_REGULAR))
 	{
-		logmsg = g_strdup_printf("StorageAgent::readProfile : Profile for user %s exists.", username);
-		cem_add_to_log(logmsg,J_LOG_DEBUG);
-		g_free(logmsg);
-		
 		// Get the file content
 		if(!g_file_get_contents(filename,&contents,(gsize*)&length,&error))
 		{
@@ -550,11 +546,6 @@ gint StorageAgent::readProfile(gchar* username)
 				if(filename) g_free(filename);
 				return PROFILE_READ_FAILURE;
 			}
-			
-			logmsg = g_strdup_printf("StorageAgent::readProfile : Profile length %d bytes.", length);
-			cem_add_to_log(logmsg,J_LOG_DEBUG);
-			g_free(logmsg);
-			
 			// Free existing
 			if(salt) g_free(salt);
 			
@@ -576,13 +567,9 @@ gint StorageAgent::readProfile(gchar* username)
 			}
 			else
 			{
-				logmsg = g_strdup_printf("StorageAgent::readProfile : Profile version ok.");
-				cem_add_to_log(logmsg,J_LOG_DEBUG);
-				g_free(logmsg);
-			
 				// Extract salt
-				salt = (guchar*)g_malloc(sizeof(guchar*) * AES_SALT_LENGTH);
-				memset(salt,0,AES_SALT_LENGTH);
+				salt = g_new0(guchar,sizeof(guchar) * AES_SALT_LENGTH);
+
 				*(guint32*)&salt[0] = *(guint32*)&contents[1];
 				*(guint32*)&salt[sizeof(guint32)] = *(guint32*)&contents[sizeof(guint32)+1];
 			
@@ -590,16 +577,14 @@ gint StorageAgent::readProfile(gchar* username)
 				if(password_hash) g_free(password_hash);
 			
 				// Extract password hash
-				password_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
-				memset(password_hash,0,SHA_HASH_LENGTH + 1);
+				password_hash = g_new0(guchar,sizeof(guchar) * (SHA_HASH_LENGTH + 1));
 				g_memmove(password_hash,&contents[AES_SALT_LENGTH + 1],SHA_HASH_LENGTH);
 			
 				// Free existing
 				if(profile_hash) g_free(profile_hash);
 			
 				// Extract profile hash
-				profile_hash = (guchar*)g_malloc(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
-				memset(profile_hash,0,SHA_HASH_LENGTH + 1);
+				profile_hash = g_new0(guchar,sizeof(guchar) * (SHA_HASH_LENGTH + 1));
 				g_memmove(profile_hash,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + 1],SHA_HASH_LENGTH);
 			
 				// Free existing
@@ -607,8 +592,7 @@ gint StorageAgent::readProfile(gchar* username)
 			
 				// Extract encrypted profile
 				encrypted_profile_size = length - SHA_HASH_LENGTH - SHA_HASH_LENGTH - AES_SALT_LENGTH - 1;
-				encrypted_profile = (guchar*)g_malloc(sizeof(guchar*) * (encrypted_profile_size));
-				memset(encrypted_profile,0,encrypted_profile_size);
+				encrypted_profile = g_new0(guchar,sizeof(guchar) * (encrypted_profile_size));
 				g_memmove(encrypted_profile,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + 1],encrypted_profile_size);
 	
 				// copy the username
@@ -638,7 +622,7 @@ gint StorageAgent::readProfile(gchar* username)
 
 // Write encrypted profile - raw
 // username, password hash, encrypted profile data, profile data hash
-gint StorageAgent::writeProfile(gchar* username)
+gint StorageAgent::writeProfile(const gchar* username)
 {
 	gchar* profilefile = g_strjoin(NULL,username,PROFILE_FILE_EXT,NULL);
 	gchar* filename = g_build_filename(configure_get_jammo_directory(),JAMMOPROFILE,profilefile,NULL);
@@ -661,8 +645,7 @@ gint StorageAgent::writeProfile(gchar* username)
 	if(encrypted_profile_size == 0) return 6;
 	if(version != JAMMO_PROFILE_VERSION) return 7;	
 	
-	gchar* content = (gchar*)g_malloc(sizeof(gchar*) * length);
-	memset(content,0,length);
+	gchar* content = g_new0(gchar,sizeof(gchar) * length);
 	
 	// Set version
 	*(guint8*)&content[0] = version;
