@@ -176,7 +176,7 @@ int decode_start_game_response(char* message,int length, int id)
 {
 	char location;
 	gint16 messagelength;
-	gint16 stat, status;
+	gint16 stat_temp, status;
 
 	location=sizeof(gint16);//MessageID
 	memcpy(&messagelength,message+location,sizeof(gint16));
@@ -184,9 +184,9 @@ int decode_start_game_response(char* message,int length, int id)
 	if(length<g_ntohs(messagelength))	
 		return -1;
 	
-	memcpy(&stat,message+location,sizeof(gint16));
+	memcpy(&stat_temp,message+location,sizeof(gint16));
 	location=location+sizeof(gint16);
-	status=g_ntohs(stat);
+	status=g_ntohs(stat_temp);
 
 
 	//Send information about request to chum?
@@ -216,7 +216,8 @@ void collaboration_pair_game_joined(gems_components* data)
 	//Still waiting for song file
 }
 
-void collaboration_got_song_info(gems_components* data, const gchar song_info[])
+// TODO verify that this doesn't require the GLOBAL song_info - input parameter name changed because of shadowing
+void collaboration_got_song_info(gems_components* data, const gchar song_info_inp[])
 {
 	gchar* logmsg = NULL;
 
@@ -224,14 +225,14 @@ void collaboration_got_song_info(gems_components* data, const gchar song_info[])
 	cem_add_to_log(logmsg,J_LOG_DEBUG);
 	g_free(logmsg);
 
-	gchar * songinfo = g_strdup(song_info);
+	gchar * songinfo = g_strdup(song_info_inp);
 	collaboration_set_song_info(songinfo);
 	g_free(songinfo);
 
 	//TODO handle the file contents and start correct UI
 	if (data->service_group->group_info->type==GROUP_TYPE_PAIR) {
 		chum_callback_game(data->service_collaboration->collaboration_game,
-			GEMS_GAME_JOINED_PAIR_COMPOSITION, song_info);
+			GEMS_GAME_JOINED_PAIR_COMPOSITION, song_info_inp);
 	}
 
 	data->service_collaboration->active=TRUE;
