@@ -102,10 +102,10 @@ gint gems_communication_search_jammos()
 	g_timer_start(testtimer);	
 	
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE; // no PeerHood = no network
+	if(gems_get_peerhood() == NULL) return FALSE; // no PeerHood = no network
 	
 	// Get surrounding devices with service JAMMO_SERVICE_NAME 
-	TDeviceList* list = ph_c_get_devicelist_with_services(data->ph,JAMMO_SERVICE_NAME);
+	TDeviceList* list = ph_c_get_devicelist_with_services(gems_get_peerhood(),JAMMO_SERVICE_NAME);
 	
 	// Got a NULL reference - error with PeerHood -> stop it
 	if(list == NULL)
@@ -175,7 +175,7 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 
 	if(gems_connection_error_attempt_connection(data->connection_errorlist,ph_c_device_get_checksum(device)) == TRUE)
 	{
-		if((conn = ph_c_connect_remoteservice(data->ph, device, JAMMO_SERVICE_NAME)) != NULL)
+		if((conn = ph_c_connect_remoteservice(gems_get_peerhood(), device, JAMMO_SERVICE_NAME)) != NULL)
 		{
 			// Connection success, remove from errors. If no such device in the list, nothing is done
 			data->connection_errorlist = gems_connection_error_remove(data->connection_errorlist,ph_c_device_get_checksum(device)); 
@@ -248,7 +248,7 @@ gint gems_communication_retrieve_profiles()
 	g_timer_start(testtimer);
 	
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
 	gboolean cleanup_required = FALSE;
@@ -319,7 +319,7 @@ gint gems_communication_request_groups()
 	g_timer_start(testtimer);
 
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
 	gboolean cleanup_required = FALSE;
@@ -392,7 +392,7 @@ gint gems_communication_advert_group()
 	gems_components* data = gems_get_data();
 	
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
 	g_timer_start(testtimer);
@@ -467,7 +467,7 @@ gint gems_communication_sanitize_grouplist()
 {
 	gems_components* data = gems_get_data();
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	if(data->service_group == NULL) return FALSE;
 	
@@ -508,7 +508,7 @@ gint gems_communication_process_connecting()
 {
 	gems_components* data = gems_get_data();
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
 	// Check connecting list
@@ -521,7 +521,7 @@ gint gems_communication_process_rejected()
 {
 	gems_components* data = gems_get_data();
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
 	// Check rejected list
@@ -718,12 +718,14 @@ gboolean gems_communication_write_encrypted_data(guint16 type, gems_connection*
 // Write message to socket
 gint gems_communication_write_data(gint sock_fd, gems_message* data)
 {
+	if(!data) return -1;
 	return write(sock_fd, (gchar*)data->message, data->length);
 }
 
 // Read data from socket, place data in gpointer* data
 gint gems_communication_read_data(gint sock_fd, void* data, gint length)
 {
+	if(!data || length == 0) return -1;
 	return read(sock_fd, (gchar*)data, length);
 }
 
@@ -739,7 +741,7 @@ gint gems_communication_process_connected()
 	gint bytesread = -1;
 	
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE;
+	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
 	// Check if we have a teacher connection
@@ -974,6 +976,8 @@ gboolean gems_communication_process_data(gems_connection* element)
 	gboolean success = TRUE;
 	gems_message* err = NULL;
 	gchar* logmsg = NULL;
+	gems_teacher_connection* tc = NULL;
+	gboolean teacher_message=FALSE;
 	
 	if(data == NULL) return FALSE;
 	if(data->service_profile == NULL) return FALSE;
@@ -1103,9 +1107,21 @@ gboolean gems_communication_process_data(gems_connection* element)
 			}
 			break;
 		case GROUP_SERVICE_ID:
-			// check that profile is requested!
+			tc = gems_get_teacher_connection();
+			// Connection to teacher exists
+			if(tc)
+			{
+				// Is connected
+				if(gems_teacher_connection_is_connected())
+				{
+					// Message is coming from teacher
+					if(ph_c_connection_get_device_checksum(tc->connection->connection) == ph_c_connection_get_device_checksum(element->connection))
+					teacher_message=TRUE;
+				}
+			}
+			// check that profile is requested! (or message from teacher)
 			// TODO create a better system - request profile directly
-			if(element->profile == NULL) break;
+			if(element->profile == NULL && !teacher_message) break;
 			// Check that service is running
 			if(data->service_group->enabled == TRUE) success = gems_service_group_process_request(element);
 			else
@@ -1244,7 +1260,7 @@ void gems_communication_process_error(gems_connection* element)
 							if(tc)
 							{
 								// Is connected
-								if(ph_c_connection_is_connected(tc->connection->connection) == TRUE)
+								if(gems_teacher_connection_is_connected())
 								{
 									// Message is coming from teacher
 									if(ph_c_connection_get_device_checksum(tc->connection->connection) == ph_c_connection_get_device_checksum(element->connection))
@@ -1556,17 +1572,19 @@ gint gems_communication_probe_for_peerhood()
 	if(ph_c_init(data->ph,1,args) == TRUE)
 	{
 		gems_register_services();
+		data->ph_on = TRUE;
 		gems_enable_network_timeout_functions();
 		logmsg = g_strdup_printf("gems_networking_probe_for_peerhood: initialized and re-enabled timeout functions.");
-		cem_add_to_log(logmsg,J_LOG_NETWORK);
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		g_free(args);
+		if(data->timeout_functions[10] != 0) g_source_remove(data->timeout_functions[10]);
 		return FALSE; // Got connection, remove
 	}
 	else
 	{
 		logmsg = g_strdup_printf("gems_networking_probe_for_peerhood: cannot initialize peerhood.");
-		cem_add_to_log(logmsg,J_LOG_NETWORK);
+		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 		g_free(args);
 		return TRUE;
@@ -1581,49 +1599,36 @@ void gems_communication_peerhood_close_detected()
 	
 	if(data == NULL) return;
 	
-	logmsg = g_strdup_printf("gems_networking_peerhood_close_detected.");
-	cem_add_to_log(logmsg,J_LOG_NETWORK);
+	logmsg = g_strdup_printf("gems_networking_peerhood_close_detected: detected peerhood daemon close. Disabling services and to-functions. ");
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 	g_free(logmsg);
 	
-	if(data->ph == NULL)
-	{
-		logmsg = g_strdup_printf("gems_networking_peerhood_close_detected: PeerHood NULL.");
-		cem_add_to_log(logmsg,J_LOG_NETWORK);
-		g_free(logmsg);
-	}
-	else
-	{
-		ph_c_delete_peerhood(data->ph);
-		data->ph = NULL;
-		
-		//ph_c_delete_callback(data->ph_cb);
-		//data->ph_cb = NULL;
-	}
+	// Set Peerhood "off"
+	data->ph_on = FALSE;
 	
+	// Disable services (cannot unregister hence no connection)
 	data->service_jammo->enabled = FALSE;
 	data->service_profile->enabled = FALSE;
 	data->service_group->enabled = FALSE;
 	data->service_collaboration->enabled = FALSE;
-		
+	data->service_control->enabled = FALSE;
 	
-	/*jammo_gems_cleanup_lists();
-	printf("jammo_gems_cleanup_lists\n");
-
+	// Cleanup lists from previous connections - not valid anymore
+	// TODO Check the behaviour if lists are not cleared - connections are not daemon dependant
+	jammo_gems_cleanup_lists();
 	gems_communication_cleanup_lists();
-	printf("gems_networking_cleanup_lists\n");*/
-	
-	// TODO create and user cleanup_lists() of each service
-	/*gems_service_jammo_cleanup_lists();
+	gems_service_jammo_cleanup_lists();
 	gems_service_profile_cleanup_lists();
 	gems_service_group_cleanup_lists();
 	gems_service_collaboration_cleanup_lists();
 	
-	*/
-	/*
-	g_timeout_add_full(G_PRIORITY_LOW,2000,(GSourceFunc)gems_communication_probe_for_peerhood, NULL, NULL);
-	logmsg = g_strdup_printf("gems_networking_peerhood_close_detected: deleted, timeout for probe added.");
-	cem_add_to_log(logmsg,J_LOG_INFO);
-	g_free(logmsg);*/
+	// Remove timeout functions
+	for(gint i = 0; i < TO_FUNCTIONS; i++) if(data->timeout_functions[i] != 0) g_source_remove(data->timeout_functions[i]);
+	
+	data->timeout_functions[10] = g_timeout_add_full(G_PRIORITY_HIGH,2000,(GSourceFunc)gems_communication_probe_for_peerhood, NULL, NULL);
+	logmsg = g_strdup_printf("gems_networking_peerhood_close_detected: probing for peerhood started.");
+	cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
+	g_free(logmsg);
 	
 }
 
@@ -1721,11 +1726,11 @@ gint gems_communication_search_teacher()
 	gems_components* data = gems_get_data();	
 	
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE; // no PeerHood = no network
+	if(gems_get_peerhood() == NULL) return FALSE; // no PeerHood = no network
 	if(gems_teacher_connection_is_connected()) return FALSE; // Already connected
 	
 	// Get surrounding devices with service JAMMO_SERVICE_NAME 
-	TDeviceList* list = ph_c_get_devicelist_with_services(data->ph,MENTOR_SERVICE_NAME);
+	TDeviceList* list = ph_c_get_devicelist_with_services(gems_get_peerhood(),MENTOR_SERVICE_NAME);
 	// Got a NULL reference - error with PeerHood -> stop it
 	if(list == NULL)
 	{
