@@ -43,6 +43,7 @@ gems_components* gems_get_data()
 		gems_data = g_new0(gems_components,sizeof(gems_components));
 		gems_data->pm = NULL;
 		gems_data->ph = NULL;
+		gems_data->ph_on = FALSE;
 		gems_data->ph_cb = NULL;
 		gems_data->communication = NULL;
 		gems_data->security_context = NULL;
@@ -73,12 +74,13 @@ ProfileManager* gems_get_profile_manager()
 
 MPeerHood* gems_get_peerhood()
 {
-	return gems_get_data()->ph;
+	if(gems_peerhood_enabled()) return gems_get_data()->ph;
+	else return NULL;
 }
 
 gboolean gems_peerhood_enabled()
 {
-	return TRUE; // TODO add ph_on boolean
+	return gems_get_data()->ph_on;
 }
 
 GList* gems_get_initialized_connections()
@@ -287,21 +289,21 @@ void jammo_gems_init(int argc, char* argv[])
 	// Initialize teacher connection
 	components->teacher_connection = gems_teacher_connection_init();
 	
-	// Define function pointers for notify and new connection functions
-	void (*notify)(short, const char*,void*) = NULL;
-	notify = &gems_ph_callback_notify;
-
-	void (*newconnection)(const unsigned short, MAbstractConnection*, int,void*) = NULL;
-	newconnection = &gems_ph_callback_newconnection;
+	// Create callback
+	gems_init_peerhood_callback();
 	
-	// Callback and instance of PeerHood
-	components->ph_cb = ph_c_create_callback(notify, newconnection,(void*)components,(void*)components);
+	// Get PeerHood instance
 	components->ph = ph_c_get_instance(components->ph_cb);
 	
-	if(ph_c_init(components->ph,argc,argv) == TRUE) gems_register_services();
+	if(ph_c_init(components->ph,argc,argv) == TRUE)
+	{
+		gems_register_services();
+		components->ph_on = TRUE;
+	}
 	else
 	{
-		logmsg = g_strdup_printf("NO PEERHOOD RUNNING - NETWORKING DISABLED");
+		components->ph_on = FALSE;
+		logmsg = g_strdup_printf("No PeerHood running, probing of peerhood enabled.");
 		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 		
@@ -310,17 +312,15 @@ void jammo_gems_init(int argc, char* argv[])
 		components->service_group->enabled = FALSE;
 		components->service_collaboration->enabled = FALSE;
 		components->service_control->enabled = FALSE;
-		//gems_service_jammo_cleanup(components->service_jammo);
-		
-		//gems_communication_cleanup(components->communication);
 		
+		/* No need to delete these...
 		ph_c_delete_peerhood(components->ph);
 		components->ph = NULL;
 		
 		ph_c_delete_callback(components->ph_cb);
-		components->ph_cb = NULL;
+		components->ph_cb = NULL;*/
 		
-		//g_timeout_add_full(G_PRIORITY_LOW,2000,(GSourceFunc)gems_communication_probe_for_peerhood, NULL, NULL);
+		components->timeout_functions[10] = g_timeout_add_full(G_PRIORITY_HIGH,2000,(GSourceFunc)gems_communication_probe_for_peerhood, NULL, NULL);
 	}
 	
 
@@ -368,40 +368,40 @@ void jammo_gems_cleanup()
 	// Clear Profile service related
 	if(components->service_profile)
 	{
-		if(components->service_profile->enabled == TRUE) ph_c_unregister_service(components->ph,PROFILE_SERVICE_NAME);
+		if(components->service_profile->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,PROFILE_SERVICE_NAME);
 		gems_service_profile_cleanup();
 	}
 	
 	// Clear JamMo service related
 	if(components->service_jammo)
 	{
-		if(components->service_jammo->enabled == TRUE) ph_c_unregister_service(components->ph,JAMMO_SERVICE_NAME);
+		if(components->service_jammo->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,JAMMO_SERVICE_NAME);
 		gems_service_jammo_cleanup();
 	}
 	
 	// Clear Group management service related
 	if(components->service_group)
 	{
-		if(components->service_group->enabled == TRUE) ph_c_unregister_service(components->ph,GROUP_SERVICE_NAME);
+		if(components->service_group->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,GROUP_SERVICE_NAME);
 		gems_service_group_cleanup();
 	}
 	
 	// Clear Collaboration service related
 	if(components->service_collaboration)
 	{
-		if(components->service_collaboration->enabled == TRUE) ph_c_unregister_service(components->ph,COLLABORATION_SERVICE_NAME);
+		if(components->service_collaboration->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,COLLABORATION_SERVICE_NAME);
 		gems_service_collaboration_cleanup();
 	}
 	
 	if(components->service_control)
 	{
-		if(components->service_control->enabled == TRUE) ph_c_unregister_service(components->ph,CONTROL_SERVICE_NAME);
+		if(components->service_control->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,CONTROL_SERVICE_NAME);
 		gems_service_control_cleanup();
 	}
 
 	if(components->service_mentor)
 	{
-		if(components->service_mentor->enabled == TRUE) ph_c_unregister_service(components->ph,MENTOR_SERVICE_NAME);
+		if(components->service_mentor->enabled == TRUE && gems_peerhood_enabled()) ph_c_unregister_service(components->ph,MENTOR_SERVICE_NAME);
 		gems_service_mentor_cleanup();
 	}
 	
@@ -431,8 +431,6 @@ void jammo_gems_cleanup()
 	}
 	
 	// Free the structure
-	//g_free(components);
-	//components = NULL;
 	gems_free_data();
 	
 	logmsg = g_strdup_printf("jammo_gems_cleanup: done");
@@ -575,6 +573,15 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 	components = (gems_components*)aData;
 
 	// TODO add check that the other end is using WLAN atm
+	
+	// If there is no connection to Peerhood daemon all inbound connections are dropped
+	if(!gems_peerhood_enabled())
+	{
+		cem_add_to_log("gems_ph_callback_newconnection: Got new connection while connection to peerhoodd does not exist, disconnecting",
+			J_LOG_NETWORK_DEBUG);
+		ph_c_connection_delete(aConnection);
+		return;
+	}
 
 	if(components != NULL)
 	{
@@ -922,7 +929,7 @@ gint gems_process_connections()
 	
 	gboolean cleanup_required = FALSE;
 	if(data == NULL) return FALSE;
-	if(data->ph == NULL) return FALSE; // No PeerHood - no networking
+	if(gems_get_peerhood() == NULL) return FALSE; // No PeerHood - no networking
 
 	gems_connection* element = NULL;
 	GList* iterator = NULL;
