@@ -322,7 +322,7 @@ void gems_service_collaboration_handle_song_info(gems_components* data, gems_con
 
 gems_service_collaboration* gems_service_collaboration_init()
 {
-	gems_service_collaboration* data = (gems_service_collaboration*)g_malloc(sizeof(gems_service_collaboration));
+	gems_service_collaboration* data = g_new(gems_service_collaboration,sizeof(gems_service_collaboration));
 	
 	data->enabled = FALSE;
 
