@@ -164,21 +164,21 @@ void gems_service_group_handle_current_group(gems_components* data, gems_connect
 			if(data->service_group->group_info->owner != gems_profile_manager_get_userid(NULL))
 			{	
 				// Get owner of the group
-				gems_connection* element = gems_communication_get_connection_with_userid(data->communication->connections, data->service_group->group_info->owner);
+				gems_connection* owner_element = gems_communication_get_connection_with_userid(data->communication->connections, data->service_group->group_info->owner);
 		
 				msg = gems_create_message_group_management_notify(REQUEST_MEMBERS, 0, 0);
 			
-				if(element != NULL)
+				if(owner_element != NULL)
 				{
-					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
+					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, owner_element, msg) == FALSE)
 					{
 						logerror = g_strdup_printf("gems_service_group_handle_current_group: cannot write REQUEST_MEMBERS to group owner id %u (%s/%u)", 
-							data->service_group->group_info->owner, ph_c_connection_get_remote_address(element->connection), 
-							ph_c_connection_get_device_checksum(element->connection));
+							data->service_group->group_info->owner, ph_c_connection_get_remote_address(owner_element->connection), 
+							ph_c_connection_get_device_checksum(owner_element->connection));
 					}
 				}
 				else logmsg = g_strdup_printf("gems_service_group_handle_current_group: wrote REQUEST_MEMBERS to %s/%u", 
-					ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+					ph_c_connection_get_remote_address(owner_element->connection), ph_c_connection_get_device_checksum(owner_element->connection));
 
 				gems_clear_message(msg);
 			}
@@ -880,14 +880,14 @@ void gems_service_group_handle_new_member(gems_components* data, gems_connection
 					msg = gems_create_message_group_management_notify(REQUEST_MEMBERS, 0, 0);
 		
 					// Get owner of the group
-					gems_connection* element = gems_communication_get_connection_with_userid(data->communication->connections, data->service_group->group_info->owner);
+					gems_connection* owner_element = gems_communication_get_connection_with_userid(data->communication->connections, data->service_group->group_info->owner);
 		
-					if(element != NULL)
+					if(owner_element != NULL)
 					{
-						if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
+						if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, owner_element, msg) == FALSE)
 						{
 							logerror = g_strdup_printf("gems_service_group_handle_new_member: cannot write REQUEST_MEMBERS to group owner id %u (%s/%u)", 
-								data->service_group->group_info->owner,ph_c_connection_get_remote_address(element->connection), ph_c_connection_get_device_checksum(element->connection));
+								data->service_group->group_info->owner,ph_c_connection_get_remote_address(owner_element->connection), ph_c_connection_get_device_checksum(owner_element->connection));
 						}
 					}
 					gems_clear_message(msg);
@@ -1045,7 +1045,7 @@ void gems_service_group_handle_member_list(gems_components* data, gems_connectio
 
 gems_service_group* gems_service_group_init()
 {
-	gems_service_group* data = (gems_service_group*)g_malloc(sizeof(gems_service_group));
+	gems_service_group* data = g_new(gems_service_group,sizeof(gems_service_group));
 	
 	data->enabled = FALSE;
 	
