@@ -80,7 +80,7 @@ gboolean gems_service_profile_process_request(gems_connection* element)
 				if(tc)
 				{
 					// Is connected
-					if(ph_c_connection_is_connected(tc->connection->connection) == TRUE)
+					if(gems_teacher_connection_is_connected())
 					{
 						// Message is coming from teacher
 						if(ph_c_connection_get_device_checksum(tc->connection->connection) == ph_c_connection_get_device_checksum(element->connection))
@@ -212,7 +212,7 @@ gboolean gems_service_profile_process_profile_upload(gems_connection* element)
 	if(tc)
 	{
 		// Is connected
-		if(ph_c_connection_is_connected(tc->connection->connection) == TRUE)
+		if(gems_teacher_connection_is_connected())
 		{
 			// Message is coming from teacher
 			if(ph_c_connection_get_device_checksum(tc->connection->connection) == ph_c_connection_get_device_checksum(element->connection))
