@@ -151,6 +151,18 @@ double gems_connection_get_last_action(gems_connection* element)
 	return g_timer_elapsed(element->last_action,NULL);
 }
 
+void gems_connection_clear_last_action(gems_connection* element)
+{
+	if(element)
+	{
+		if(element->last_action)
+		{
+			g_timer_destroy(element->last_action);
+			element->last_action = NULL;
+		}
+	}
+}
+
 // Add 16bit integer to network buffer
 void gems_connection_add_16(gems_connection* element, guint16 value)
 {
@@ -639,6 +651,9 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 {
 	gchar* logmsg = NULL;
 	gems_connection_error* item = NULL;
+	GRand* rand = NULL;
+	
+	if(errortype == ERROR_ALREADY_CONNECTED) rand = g_rand_new_with_seed(time(NULL));
 	
 	// Not found -> create new and add
 	if((item = gems_connection_error_get(list,device_checksum)) == NULL)
@@ -652,8 +667,16 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 		if(errortype == ERROR_REJECTED) item->version_mismatch = TRUE;
 		else item->version_mismatch = FALSE;
 		
-		if(errortype == ERROR_ALREADY_CONNECTED) item->already_connected = TRUE;
-		else item->already_connected = FALSE;
+		if(errortype == ERROR_ALREADY_CONNECTED)
+		{
+			item->already_connected = TRUE;
+			item->already_connected_delay = g_rand_double_range(rand,AC_DELAY_LOW,AC_DELAY_HIGH);
+		}
+		else
+		{
+			item->already_connected = FALSE;
+			item->already_connected_delay = 0.0;
+		}
 		
 		item->connection_timer = g_timer_new();
 		g_timer_start(item->connection_timer);
@@ -674,8 +697,11 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 				item->version_mismatch = TRUE;
 				break;
 			case ERROR_ALREADY_CONNECTED:
+			{
 				item->already_connected = TRUE;
+				item->already_connected_delay = g_rand_double_range(rand,AC_DELAY_LOW,AC_DELAY_HIGH);
 				break;
+			}
 			default:
 				break;
 		}
@@ -684,6 +710,8 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 		cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 	}
+	
+	if(rand) g_rand_free(rand);
 	return list;
 }
 
@@ -733,7 +761,12 @@ gboolean gems_connection_error_attempt_connection(GList* list, guint device_chec
 		//logmsg = g_strdup_printf("gems_connection_error_attempt_connection: checking time for %d, time = %f, errors = %d", item->checksum, time, item->connection_errors);
 		
 		if(item->version_mismatch) return FALSE;
-		if(item->already_connected) return FALSE;
+		if(item->already_connected)
+		{
+			// Connection delay expired
+			if(g_timer_elapsed(item->connection_timer,NULL) > item->already_connected_delay) return TRUE;
+			else return FALSE;
+		}
 		
 		// less than 'time' elapsed?
 		if(g_timer_elapsed(item->connection_timer,NULL) < err_time)
