@@ -16,7 +16,7 @@
 
 jammo_profile_container* gems_teacher_server_new_profile_container()
 {
-	jammo_profile_container* container = (jammo_profile_container*)g_malloc(sizeof(jammo_profile_container));
+	jammo_profile_container* container = g_new(jammo_profile_container,sizeof(jammo_profile_container));
 	// Allocation failed?
 	if(container == NULL) return NULL;
 	
@@ -39,7 +39,7 @@ jammo_profile_container* gems_teacher_server_new_profile_container()
 
 teacher_server_profile_data* gems_teacher_server_new_profile_data_container()
 {
-	teacher_server_profile_data* data = (teacher_server_profile_data*)g_malloc(sizeof(teacher_server_profile_data));
+	teacher_server_profile_data* data = g_new(teacher_server_profile_data,sizeof(teacher_server_profile_data));
 	
 	if(data == NULL) return NULL;
 	
@@ -85,15 +85,15 @@ void gems_teacher_server_clear_profile_data_container(teacher_server_profile_dat
 	}	
 }
 
-jammo_profile_container* gems_teacher_server_create_profile(guint8 _type, guint32 _userid, gchar* _username, gchar* _password,
-	gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _avatarid)
+jammo_profile_container* gems_teacher_server_create_profile(guint8 _type, guint32 _userid, const gchar* _username, const gchar* _password,
+	const gchar* _authlevel, const gchar* _firstname, const gchar* _lastname, guint16 _age, guint32 _avatarid)
 {
 	// Call setup function with NULL salt and 0 points, salt will be generated when NULL
 	return gems_teacher_server_setup_profile(_type, _userid,_username,_password,NULL,_authlevel,_firstname,_lastname,_age,0,_avatarid);
 }
 
-jammo_profile_container* gems_teacher_server_setup_profile(guint8 _type, guint32 _userid, gchar* _username, gchar* _password,
-	guchar* _salt, gchar* _authlevel, gchar* _firstname, gchar* _lastname, guint16 _age, guint32 _points, guint32 _avatarid)
+jammo_profile_container* gems_teacher_server_setup_profile(guint8 _type, guint32 _userid, const gchar* _username, const gchar* _password,
+	guchar* _salt, const gchar* _authlevel, const gchar* _firstname, const gchar* _lastname, guint16 _age, guint32 _points, guint32 _avatarid)
 {
 	// check input
 	if((_userid == 0) || (_username == NULL) || (_password == NULL) || (_authlevel == NULL) 
@@ -126,7 +126,7 @@ jammo_profile_container* gems_teacher_server_setup_profile(guint8 _type, guint32
 	else
 	{
 		// set salt
-		container->salt = (guchar*)g_malloc0(sizeof(guchar*)*AES_SALT_LENGTH);
+		container->salt = g_new0(guchar,sizeof(guchar)*AES_SALT_LENGTH);
 		g_memmove(&container->salt[0],_salt,AES_SALT_LENGTH);
 	}
 
@@ -233,8 +233,7 @@ gboolean gems_teacher_server_encrypt_profile(jammo_profile_container* container)
 				
 				// Allocate content, free old if it was allocated
 				if(container->encrypted != NULL) g_free(container->encrypted);
-				container->encrypted = (gchar*)g_malloc(sizeof(gchar*) * container->encrypted_length);
-				memset(container->encrypted,0,container->encrypted_length);
+				container->encrypted = g_new0(gchar,sizeof(gchar) * container->encrypted_length);
 	
 				// set into beginning
 				*(guint8*)&container->encrypted[0] = container->version;
@@ -335,7 +334,7 @@ gboolean gems_teacher_server_save_encrypted_profile(gchar* username, gchar* prof
 	jammo_profile_container* container = gems_teacher_server_new_profile_container();
 	
 	container->username = g_strdup(username);
-	container->encrypted = (gchar*)g_malloc0(sizeof(gchar*)*datalength);
+	container->encrypted = g_new0(gchar,sizeof(gchar)*datalength);
 	g_memmove(container->encrypted,profiledata,datalength);
 	container->encrypted_length = datalength;
 
@@ -472,7 +471,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// username
-		username = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
+		username = g_new0(gchar,sizeof(gchar)*(valuelength));
 		g_memmove(username,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -481,12 +480,12 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// password
-		password = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
+		password = g_new0(gchar,sizeof(gchar)*(valuelength));
 		g_memmove(password,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
 		// salt
-		salt = (guchar*)g_malloc0(sizeof(guchar*)*AES_SALT_LENGTH);
+		salt = g_new0(guchar,sizeof(guchar)*AES_SALT_LENGTH);
 		g_memmove(&salt[0],&serialized_data[position],AES_SALT_LENGTH);
 		position = position + AES_SALT_LENGTH;
 		
@@ -495,7 +494,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// firstname
-		firstname = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
+		firstname = g_new0(gchar,sizeof(gchar)*(valuelength));
 		g_memmove(firstname,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -504,7 +503,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// lastname
-		lastname = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
+		lastname = g_new0(gchar,sizeof(gchar)*(valuelength));
 		g_memmove(lastname,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -513,7 +512,7 @@ GList* gems_teacher_server_deserialize_profiles(GList* list, gchar* serialized_d
 		position++;
 		
 		// authlevel
-		authlevel = (gchar*)g_malloc0(sizeof(gchar*)*(valuelength));
+		authlevel = g_new0(gchar,sizeof(gchar)*(valuelength));
 		g_memmove(authlevel,&serialized_data[position],valuelength);
 		position = position + valuelength;
 		
@@ -570,7 +569,7 @@ void gems_teacher_server_print_profile(jammo_profile_container* profile)
 }
 
 // serialize all data and encrypt
-gboolean gems_teacher_server_encrypt_profiles(teacher_server_profile_data* data, gchar* passwd)
+gboolean gems_teacher_server_encrypt_profiles(teacher_server_profile_data* data, const gchar* passwd)
 {
 	gboolean rval = TRUE;
 	gchar* serialized = NULL;
@@ -634,7 +633,7 @@ gboolean gems_teacher_server_encrypt_profiles(teacher_server_profile_data* data,
 }
 
 // decrypt data-field content and add pass decrypted to deserialization
-gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data, gchar* passwd)
+gboolean gems_teacher_server_decrypt_profiles(teacher_server_profile_data* data, const gchar* passwd)
 {
 	gboolean rval = TRUE;
 	guchar* password = NULL;
@@ -723,7 +722,7 @@ gint gems_teacher_server_write_profile_database(teacher_server_profile_data* dat
 	
 	contentlength = AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + data->datalength;
 			
-	content = (gchar*)g_malloc0(sizeof(gchar*) * contentlength);
+	content = g_new0(gchar,sizeof(gchar) * contentlength);
 
 	// Set salt
 	*(guint32*)&content[0] = *(guint32*)&data->salt[0];
@@ -777,24 +776,24 @@ gint gems_teacher_server_read_profile_database(teacher_server_profile_data** dat
 		{
 			// Extract salt
 			if((*data)->salt != NULL) g_free((*data)->salt);
-			(*data)->salt = (guchar*)g_malloc0(sizeof(guchar*) * AES_SALT_LENGTH);
+			(*data)->salt = g_new0(guchar,sizeof(guchar) * AES_SALT_LENGTH);
 			*(guint32*)&(*data)->salt[0] = *(guint32*)&contents[0];
 			*(guint32*)&(*data)->salt[sizeof(guint32)] = *(guint32*)&contents[sizeof(guint32)];
 			
 			// Extract password hash
 			if((*data)->pwhash != NULL) g_free((*data)->pwhash);
-			(*data)->pwhash = (guchar*)g_malloc0(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
+			(*data)->pwhash = g_new0(guchar,sizeof(guchar) * (SHA_HASH_LENGTH + 1));
 			g_memmove((*data)->pwhash,&contents[AES_SALT_LENGTH],SHA_HASH_LENGTH);
 			
 			// Extract profile hash
 			if((*data)->datahash != NULL) g_free((*data)->datahash);
-			(*data)->datahash = (guchar*)g_malloc0(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
+			(*data)->datahash = g_new0(guchar,sizeof(guchar) * (SHA_HASH_LENGTH + 1));
 			g_memmove((*data)->datahash,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH],SHA_HASH_LENGTH);
 			
 			// Extract encrypted profile
 			if((*data)->data != NULL) g_free((*data)->data);
 			(*data)->datalength = length - SHA_HASH_LENGTH - SHA_HASH_LENGTH - AES_SALT_LENGTH;
-			(*data)->data = (guchar*)g_malloc0(sizeof(guchar*) * ((*data)->datalength));
+			(*data)->data = g_new0(guchar,sizeof(guchar) * ((*data)->datalength));
 			g_memmove((*data)->data,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH],(*data)->datalength);
 			
 			rval = READ_OK;
