@@ -251,7 +251,7 @@ gint gems_group_send_to_group(gems_message* msg)
 	gint rval = 1;
 	gchar* logmsg = NULL;
 	gems_components* data = gems_get_data();
-	if (data->ph == NULL)
+	if (gems_get_peerhood() == NULL)
 	{
 		//TODO: Check should networking work or not. If user is playing alone, do not log error.
 		/*
