@@ -40,10 +40,10 @@ License:LGPL 2.1
 #define JAMMO_METRONOME_DEFAULT_NOTE_VALUE 4
 
 static const GstElementDetails gst_jammo_metronome_details =
-GST_ELEMENT_DETAILS ("JamMo Metronome",
-    "Source/Audio",
-    "Metronome",
-    "Mikko Gynther <mikko.gynther@lut.fi>");
+GST_ELEMENT_DETAILS ((gchar*)"JamMo Metronome",
+   (gchar*)"Source/Audio",
+   (gchar*)"Metronome",
+   (gchar*)"Mikko Gynther <mikko.gynther@lut.fi>");
 
 #define DEFAULT_SAMPLES_PER_BUFFER   256
 #define DEFAULT_VOLUME               0.6
@@ -370,7 +370,7 @@ static gfloat produce_sound(GstJammoMetronome * src) {
 		if (src->accumulator < src->sampletable_size) {
 			/* Playing */
 			src->playing=TRUE;
-			value=( interpolation(src->accumulator-(gint)src->accumulator, sampletable[(gint)src->accumulator], sampletable[((gint)src->accumulator+1)]) /(G_MAXINT16*1.0) * scale );
+			value=( jammo_gst_do_interpolation(src->accumulator-(gint)src->accumulator, sampletable[(gint)src->accumulator], sampletable[((gint)src->accumulator+1)]) /(G_MAXINT16*1.0) * scale );
 			/* move accumulator */
 			/* 44100 is samplerate of sampletable.*/
 			src->accumulator += 44100/(src->samplerate+0.0);
