@@ -13,6 +13,7 @@
 #include "jammo-meam-private.h"
 #include "jammo-looper-loop.h"
 
+#include "../configure.h"
 #include <string.h>
 
 G_DEFINE_TYPE(JammoEditingTrack, jammo_editing_track, JAMMO_TYPE_PLAYING_TRACK);
@@ -78,8 +79,18 @@ void jammo_editing_track_add_sample(JammoEditingTrack* editing_track, JammoSampl
 	
 	editing_track->priv->samples = g_list_insert_before(editing_track->priv->samples, list, sample);
 
+	/*Looper wants filename with
+	  *fullpath
+	  *$t $p, so it can change tempo and pitch
+	*/
 	loop = g_malloc0(sizeof(JammoLooperLoop));
-	loop->filename = g_strdup(jammo_sample_get_real_filename(sample));
+	const gchar* file =jammo_sample_get_filename(sample);
+	//if it contains already fullpath, do not add anything.
+	if (strncmp(file,"/",1)==0)
+		loop->filename = g_strdup_printf("%s",file);
+	else
+		loop->filename = g_strdup_printf("%s/%s",AUDIO_DIR,file);
+
 	loop->start = position;
 	g_object_set(editing_track->priv->looper, "add-loop", loop, NULL);
 	g_free(loop->filename);
