@@ -20,7 +20,8 @@
 
 /* jammo-sample.c */
 void _jammo_sample_set_editing_track(JammoSample* sample, JammoEditingTrack* editing_track);
-GstElement* _jammo_sample_get_element(JammoSample* sample);
+guint64 _jammo_sample_get_position(JammoSample* position);
+void _jammo_sample_set_position(JammoSample* sample, guint64 position);
 
 /* jammo-track.c */
 gboolean _jammo_track_setup_element(JammoTrack* track, GstPipeline* pipeline, GstBin* bin, GstElement* sink_element);
