@@ -38,7 +38,6 @@ struct _JammoSamplePrivate {
 	guint tempo;
 	gchar* pitch;
 	JammoSequencer* sequencer;
-	GstElement* element;
 	JammoEditingTrack* editing_track;
 	guint64 start;
 };
@@ -124,6 +123,7 @@ JammoSample* jammo_sample_new_from_file_with_sequencer(const gchar* filename, Ja
  * Return value: a #JammoSample
  */
 JammoSample* jammo_sample_new_from_existing(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), NULL);
 
 	return JAMMO_SAMPLE(g_object_new(JAMMO_TYPE_SAMPLE,
 	                                 "filename", sample->priv->filename,
@@ -141,6 +141,7 @@ JammoSample* jammo_sample_new_from_existing(JammoSample* sample) {
  * Return value: the file name string
  */
 const gchar* jammo_sample_get_filename(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), NULL);
 
 	return sample->priv->filename;
 }
@@ -154,6 +155,7 @@ const gchar* jammo_sample_get_filename(JammoSample* sample) {
  * Return value: the real file name string
  */
 const gchar* jammo_sample_get_real_filename(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), NULL);
 
 	return sample->priv->real_filename;
 }
@@ -170,6 +172,8 @@ const gchar* jammo_sample_get_real_filename(JammoSample* sample) {
  * if that information is not available.
  */
 guint64 jammo_sample_get_duration(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), 0);
+
 	if (sample->priv->duration == JAMMO_DURATION_INVALID &&
 	   ((sample->priv->duration = jammo_meam_get_cached_duration(sample->priv->real_filename)) == JAMMO_DURATION_INVALID)) {
 		g_message("No cached duration for '%s', prerolling.", sample->priv->real_filename);
@@ -192,6 +196,7 @@ guint64 jammo_sample_get_duration(JammoSample* sample) {
  * stand-alone.
  */
 JammoEditingTrack* jammo_sample_get_editing_track(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), NULL);
 
 	return sample->priv->editing_track;
 }
@@ -205,6 +210,7 @@ JammoEditingTrack* jammo_sample_get_editing_track(JammoSample* sample) {
  * Return value: tempo in bpm (beats per minute).
  */
 guint jammo_sample_get_tempo(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), 0);
 	
 	return sample->priv->tempo;
 }
@@ -217,6 +223,8 @@ guint jammo_sample_get_tempo(JammoSample* sample) {
  * Sets the tempo of the sample.
  */
 void jammo_sample_set_tempo(JammoSample* sample, guint tempo) {
+	g_return_if_fail(JAMMO_IS_SAMPLE(sample));
+
 	if (sample->priv->tempo != tempo) {
 		sample->priv->tempo = tempo;
 		initialize_state(sample);
@@ -233,6 +241,7 @@ void jammo_sample_set_tempo(JammoSample* sample, guint tempo) {
  * Return value: pitch as a note (string).
  */
 const gchar* jammo_sample_get_pitch(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), NULL);
 
 	return sample->priv->pitch;
 }
@@ -245,6 +254,8 @@ const gchar* jammo_sample_get_pitch(JammoSample* sample) {
  * Sets the pitch of the sample.
  */
 void jammo_sample_set_pitch(JammoSample* sample, const gchar* pitch) {
+	g_return_if_fail(JAMMO_IS_SAMPLE(sample));
+
 	if (g_strcmp0(sample->priv->pitch, pitch)) {
 		g_free(sample->priv->pitch);
 		sample->priv->pitch = g_strdup(pitch);
@@ -254,28 +265,30 @@ void jammo_sample_set_pitch(JammoSample* sample, const gchar* pitch) {
 }
 
 /**
- * jammo_sample_get_start:
+ * jammo_sample_get_position:
  * @sample: a #JammoSample
  *
  * Returns the start time of the sample on an editing track.
  *
  * Return value: start time (guint64).
  */
-guint64 jammo_sample_get_start(JammoSample* sample) {
+guint64 _jammo_sample_get_position(JammoSample* sample) {
+	g_return_val_if_fail(JAMMO_IS_SAMPLE(sample), 0);
 
 	return sample->priv->start;
 }
 
 /**
- * jammo_sample_set_start:
+ * jammo_sample_set_position:
  * @sample: a #JammoSample
  *
  * Sets the start time of the sample on an editing track.
  *
  */
-void jammo_sample_set_start(JammoSample* sample, guint64 start) {
+void _jammo_sample_set_position(JammoSample* sample, guint64 position) {
+	g_return_if_fail(JAMMO_IS_SAMPLE(sample));
 
-	sample->priv->start=start;
+	sample->priv->start = position;
 }
 
 /**
@@ -288,6 +301,8 @@ void jammo_sample_set_start(JammoSample* sample, guint64 start) {
  * be).
  */
 void jammo_sample_play(JammoSample* sample) {
+	g_return_if_fail(JAMMO_IS_SAMPLE(sample));
+
 	jammo_sample_stop(sample);
 	play_sample(sample, FALSE);	
 }
@@ -302,6 +317,8 @@ void jammo_sample_play(JammoSample* sample) {
 void jammo_sample_stop(JammoSample* sample) {
 	GList* list;
 	
+	g_return_if_fail(JAMMO_IS_SAMPLE(sample));
+
 	for (list = play_datas; list; list = list->next) {
 		if (((PlayData*)list->data)->sample == sample) {
 			break;
@@ -327,12 +344,9 @@ void jammo_sample_stop_all(void) {
 	}
 }
 
-GstElement* _jammo_sample_get_element(JammoSample* sample) {
-
-	return sample->priv->element;
-}
-
 void _jammo_sample_set_editing_track(JammoSample* sample, JammoEditingTrack* editing_track) {
+	g_return_if_fail(JAMMO_IS_SAMPLE(sample));
+
 	sample->priv->editing_track = editing_track;
 	
 	if (sample->priv->sequencer) {
@@ -429,10 +443,6 @@ static void jammo_sample_dispose(GObject* object) {
 	JammoSample* sample;
 	
 	sample = JAMMO_SAMPLE(object);
-	if (sample->priv->element) {
-		g_object_unref(sample->priv->element);
-		sample->priv->element = NULL;
-	}
 	if (sample->priv->sequencer) {
 		g_signal_handlers_disconnect_by_func(sample->priv->sequencer, G_CALLBACK(on_sequencer_notify), sample);
 		g_object_remove_weak_pointer(G_OBJECT(sample->priv->sequencer), (gpointer*)&sample->priv->sequencer);
@@ -565,10 +575,6 @@ static gboolean preroll_bus_callback(GstBus* bus, GstMessage* message, gpointer
 		format = GST_FORMAT_TIME;
 		if (gst_element_query_duration(play_data->pipeline, &format, &duration)) {
 			play_data->sample->priv->duration = (guint64)duration;
-			g_object_set(play_data->sample->priv->element,
-				     "duration", play_data->sample->priv->duration,
-				     "media-duration", play_data->sample->priv->duration,
-				     NULL);
 			g_object_notify(G_OBJECT(play_data->sample), "duration");
 			
 			jammo_meam_set_cached_duration(play_data->sample->priv->real_filename, play_data->sample->priv->duration);
@@ -693,6 +699,7 @@ static void initialize_state(JammoSample* sample) {
 	gchar* filename;
 	gchar* s;
 	gchar* tempo_string;
+
 	filename = s = g_strdup(sample->priv->filename);
 	while ((s = strchr(s, '$'))) {
 		switch (s[1]) {
@@ -716,57 +723,15 @@ static void initialize_state(JammoSample* sample) {
 	
 	if (g_strcmp0(sample->priv->real_filename, filename)) {
 		g_free(sample->priv->real_filename);
-		//sample->priv->real_filename = filename;
-			
-		//printf("file: %s\n",filename);
-		gchar* filename_with_path;
 
-		//If filename is absolute, use it as filename_with_path
 		if (filename[0] == '/' ) {
-			filename_with_path= g_strdup_printf("%s",filename);
-		}
-		else { //If it is relative, add AUDIO_DIR prefix
-			//printf("adding AUDIO_DIR\n");
-			filename_with_path= g_strdup_printf("%s/%s",AUDIO_DIR,filename);
-		}
-		sample->priv->real_filename = g_strdup(filename_with_path);
-		//printf("file_with_path: %s\n", filename_with_path);
-		g_free(filename_with_path);
-
-
-		if (sample->priv->element) {
-			g_object_set(sample->priv->element,
-				     "location", sample->priv->real_filename,
-				     NULL);
-			if (sample->priv->duration != JAMMO_DURATION_INVALID) {
-				sample->priv->duration = JAMMO_DURATION_INVALID;
-				g_object_notify(G_OBJECT(sample), "duration");
-			}
+			sample->priv->real_filename = g_strdup_printf("%s",filename);
 		} else {
-			sample->priv->element = gst_element_factory_make("gnlfilesource", NULL);
-			//printf("sample->priv->real_filename '%s'\n",sample->priv->real_filename);
-			g_object_set(sample->priv->element,
-                    "priority", 0,
-                    "media-start", 0 * GST_SECOND,
-                    NULL);
-			//If file is missing, then real_filename is NULL. Passing location NULL causes warning.
-			//Maybe we should do something more in this (error) case?
-			if (sample->priv->real_filename) {
-				g_object_set(sample->priv->element,
-                    "location", sample->priv->real_filename,
-                    NULL);
-			}
-			if (sample->priv->duration != JAMMO_DURATION_INVALID ||
-			    (sample->priv->duration = jammo_meam_get_cached_duration(sample->priv->real_filename)) != JAMMO_DURATION_INVALID) {
-				g_object_set(sample->priv->element,
-		        		     "duration", sample->priv->duration,
-					     "media-duration", sample->priv->duration,
-					     NULL);
-			}
+			sample->priv->real_filename = g_strdup_printf("%s/%s",AUDIO_DIR,filename);
 		}
 	}
 
-	g_free(filename);//this is coming from str_replace, which allocates memory for it
+	g_free(filename);
 }
 
 static void on_sequencer_notify(JammoSample* sample) {
